@@ -852,7 +852,7 @@ diffFilter.massvectorlist <- function(object,listofdiffs,higher=TRUE,error=0.05,
   ##e data(mvl)
   ##e res<-getdiff(mvl,range=c(0,100))
   ##e hist(res)
-  ##e res<-gamasses(res,abund=400)
+  ##e res<-gamasses(res,abund=100)
   ##e test<-diffFilter(mvl,res,higher=TRUE,error=0.1,uniq=TRUE)
   ##e test
   res <- lapply(object,diffFilter, listofdiffs, higher=higher, error=error,uniq=uniq,prune=prune)
@@ -882,7 +882,7 @@ getdiff.massvectorlist<-function(object,masst="massrea",range=c(0,100),...)
   ##e tt<-gamasses(res,abund=40)
   ##e plot(tt)
   res<-massvector(NULL)
-  res<-lapply(mvl,getdiff,range=c(0,100))
+  res<-lapply(object,getdiff,range=c(0,100))
   res<-massvectorlist(experiment(object),res,project=project(object))
   res<-unlist(res)
   res<-info(res,paste(info(object),"diffs",sep="_"))
